Package: nodbi
Title: 'NoSQL' Database Connector
Description: Simplified JSON document database access and manipulation,
     providing a common API across supported 'NoSQL' databases 
     'Elasticsearch', 'CouchDB', 'MongoDB' as well as 
     'SQLite/JSON1', 'PostgreSQL', and 'DuckDB'.
Version: 0.14.0
Authors@R: c(
    person(given = "Ralf",
           family = "Herold",
           role = c("aut", "cre"),
           email = "ralf.herold@mailbox.org",
           comment = c(ORCID = "0000-0002-8148-6748")),
    person(given = "Scott", 
           family = "Chamberlain", 
           role = "aut",
           comment = c(ORCID = "0000-0003-1444-9135")),
    person("Rich", "FitzJohn", role = "aut"),
    person("Jeroen", "Ooms", role = "aut"),
    person("Ivan", "Tarbakou", role = "cph", 
           comment = "mongo-to-sql-converter library")
  )
License: MIT + file LICENSE
LazyData: true
URL: https://docs.ropensci.org/nodbi/,
        https://github.com/ropensci/nodbi
BugReports: https://github.com/ropensci/nodbi/issues
Depends: R (>= 3.4.0)
Encoding: UTF-8
Language: en-US
Imports: stringi, jsonlite, uuid, jqr, DBI, V8, R.utils
Suggests: sofa (>= 0.4.0), elastic (>= 1.2.0), mongolite (>= 4.0.0),
        RSQLite (>= 2.4.0), duckdb (>= 1.4.0), RPostgres (>= 1.4.8),
        testthat, withr, callr, webfakes, knitr, rmarkdown, tibble
RoxygenNote: 7.3.3
X-schema.org-applicationCategory: Databases
X-schema.org-keywords: database, MongoDB, Elasticsearch, CouchDB,
        SQLite, PostgreSQL, DuckDB, NoSQL, JSON, documents
X-schema.org-isPartOf: https://ropensci.org
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-12-07 08:12:11 UTC; ralfherold
Author: Ralf Herold [aut, cre] (ORCID: <https://orcid.org/0000-0002-8148-6748>),
  Scott Chamberlain [aut] (ORCID:
    <https://orcid.org/0000-0003-1444-9135>),
  Rich FitzJohn [aut],
  Jeroen Ooms [aut],
  Ivan Tarbakou [cph] (mongo-to-sql-converter library)
Maintainer: Ralf Herold <ralf.herold@mailbox.org>
Repository: CRAN
Date/Publication: 2025-12-07 08:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 03:15:36 UTC; unix
