# Generated by roxygen2: do not edit by hand

S3method(docdb_create,src_couchdb)
S3method(docdb_create,src_duckdb)
S3method(docdb_create,src_elastic)
S3method(docdb_create,src_mongo)
S3method(docdb_create,src_postgres)
S3method(docdb_create,src_sqlite)
S3method(docdb_delete,src_couchdb)
S3method(docdb_delete,src_duckdb)
S3method(docdb_delete,src_elastic)
S3method(docdb_delete,src_mongo)
S3method(docdb_delete,src_postgres)
S3method(docdb_delete,src_sqlite)
S3method(docdb_exists,src_couchdb)
S3method(docdb_exists,src_duckdb)
S3method(docdb_exists,src_elastic)
S3method(docdb_exists,src_mongo)
S3method(docdb_exists,src_postgres)
S3method(docdb_exists,src_sqlite)
S3method(docdb_get,src_couchdb)
S3method(docdb_get,src_duckdb)
S3method(docdb_get,src_elastic)
S3method(docdb_get,src_mongo)
S3method(docdb_get,src_postgres)
S3method(docdb_get,src_sqlite)
S3method(docdb_list,src_couchdb)
S3method(docdb_list,src_duckdb)
S3method(docdb_list,src_elastic)
S3method(docdb_list,src_mongo)
S3method(docdb_list,src_postgres)
S3method(docdb_list,src_sqlite)
S3method(docdb_query,src_couchdb)
S3method(docdb_query,src_duckdb)
S3method(docdb_query,src_elastic)
S3method(docdb_query,src_mongo)
S3method(docdb_query,src_postgres)
S3method(docdb_query,src_sqlite)
S3method(docdb_update,src_couchdb)
S3method(docdb_update,src_duckdb)
S3method(docdb_update,src_elastic)
S3method(docdb_update,src_mongo)
S3method(docdb_update,src_postgres)
S3method(docdb_update,src_sqlite)
S3method(print,src_couchdb)
S3method(print,src_duckdb)
S3method(print,src_elastic)
S3method(print,src_mongo)
S3method(print,src_postgres)
S3method(print,src_sqlite)
export(contacts)
export(docdb_create)
export(docdb_delete)
export(docdb_exists)
export(docdb_get)
export(docdb_list)
export(docdb_query)
export(docdb_update)
export(mapdata)
export(src_couchdb)
export(src_duckdb)
export(src_elastic)
export(src_mongo)
export(src_postgres)
export(src_sqlite)
importFrom(R.utils,countLines)
importFrom(V8,JS)
importFrom(V8,v8)
importFrom(stringi,stri_match_all_regex)
